@@ -1,14 +1,14 @@
 /* return human readable name for neb type */
 char * nebtype2str(int i) {
-    return gm_strdup("UNKNOWN");
+    return strdup("UNKNOWN");
 }
 
 /* return human readable name for nebcallback */
 char * nebcallback2str(int i) {
-    return gm_strdup("UNKNOWN");
+    return strdup("UNKNOWN");
 }
 
 /* return human readable name for eventtype */
 char * eventtype2str(int i) {
-    return gm_strdup("UNKNOWN");
+    return strdup("UNKNOWN");
 }
