@@ -177,9 +177,11 @@ int nebmodule_init( int flags, char *args, nebmodule *handle ) {
 
     /* create client */
     if ( create_client( mod_gm_opt->server_list, &client ) != GM_OK ) {
+        current_client = &client;
         gm_log( GM_LOG_ERROR, "cannot start client\n" );
         return NEB_ERROR;
     }
+    current_client = &client;
 
     /* register callback for process event where everything else starts */
     neb_register_callback( NEBCALLBACK_PROCESS_DATA, gearman_module_handle, 0, handle_process_events );
@@ -644,6 +646,9 @@ static int handle_notifications( int event_type, void *data ) {
     if(svc != NULL)
         grab_service_macros_r(&mac, svc);
 
+    /* get contact macros */
+    grab_contact_macros_r(&mac, ds->contact_ptr);
+
     /* get the raw command line */
     temp_command = find_command(ds->command_name);
     get_raw_command_line_r(&mac, temp_command, ds->command_name, &raw_command, macro_options);
@@ -883,6 +888,7 @@ static int handle_notifications( int event_type, void *data ) {
 #if defined(USENAGIOS3)
     clear_summary_macros_r(&mac);
     clear_argv_macros_r(&mac);
+    clear_contact_macros_r(&mac);
     clear_host_macros_r(&mac);
     clear_service_macros_r(&mac);
 #endif
