@@ -33,7 +33,9 @@ static const char *gearman_worker_source_name(void *source) {
     if(!source)
         return "unknown internal source (voodoo, perhaps?)";
 
-    return (char*) source;
+    // we cannot return the source here as it would be never freed
+    //return (char*) source;
+    return "Mod-Gearman Worker";
 }
 
 struct check_engine mod_gearman_check_engine = {
@@ -201,16 +203,19 @@ void *get_results( gearman_job_st *job, void *context, size_t *result_size, gear
                 chk_result->output = gm_strdup("(null)");
             }
             else {
-#ifdef USENAGIOS
-                chk_result->output = gm_strdup( value );
-#endif
-#ifdef USENAEMON
-                /* replace newlines with actual newlines */
-                char *tmp = replace_str(value, "\\n", "\n");
-                /* replace backslashes with actual backslashes */
-                chk_result->output = replace_str(tmp, "\\\\", "\\");
-                free(tmp);
-#endif
+
+                char *tmp_newline = replace_str(value, "\\n", "\n");
+                if (tmp_newline == NULL)
+                    chk_result->output = gm_strdup("(null)");
+
+                char *tmp_backslash = replace_str(tmp_newline, "\\\\", "\\");
+                if (tmp_backslash == NULL)
+                    chk_result->output = gm_strdup("(null)");
+                else
+                    chk_result->output = gm_strdup( tmp_backslash );
+
+                free(tmp_newline);
+                free(tmp_backslash);
             }
         }
 
@@ -223,7 +228,7 @@ void *get_results( gearman_job_st *job, void *context, size_t *result_size, gear
             chk_result->service_description = gm_strdup( value );
         } else if ( !strcmp( key, "source" ) ) {
 #ifdef USENAEMON
-            chk_result->source = gm_strdup( value );
+            chk_result->source = value;
 #endif
         } else if ( !strcmp( key, "check_options" ) ) {
             chk_result->check_options = atoi( value );
